# Авторы и участники SUWWP

- **Xwared|Dovintc** — создатель проекта, идея, функции, архитектура, тесты, документация, и т.п.
- **Toochic** — соавтор проекта, большее количество функций=

*Спасибо за вклад!*